@@ -1,6 +1,6 @@
 ####################################################################################################################################
 ### Filename:    Repeated.R
-### Description: Main file, where end-user functions are defined;
+### Description: Functions that process the user input; these functions are called by generic S3 methods in the file S3methods.R
 ###              EEG data example
 ###
 ###
@@ -9,8 +9,8 @@
 #' EEG data of 160 subjects
 #' 
 #' A dataset containing EEG data (Staffen et al., 2014) of 160 subjects, 4 variables are measured at ten different locations.
-#' The columns are as follows:
 #' 
+#' The columns are as follows:
 #' \itemize{
 #'   \item group. Diagnostic group of the subject: Alzheimer's Disease (AD), Mild Cognitive Impairment (MCI), Subject Cognitive Complaints (SCC+, SCC-).
 #'   \item value. Measured data of a subject at a specific variable and region.
@@ -31,60 +31,50 @@
 
 #' Test for no main treatment effect, no main time effect, no simple treatment effect and no interaction between treatment and time
 #' 
-#' @param n an vector containing the sample sizes of all groups
-#' @param a number of groups
-#' @param d number of dimensions (time points)
 #' @param data A list containing the data matrices of all groups. The rows are the independent subjects, these observations are assumed to be multivariate normally distributed. The columsn of all matrices need to be in the same order.
 #' @param alpha alpha level used for the test
 #' @return Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
-#' @example R/example_1.txt
 #' @keywords internal
-hrm.test <- function(n, a, d, data, alpha=0.05){
-  .Deprecated("hrm.test.matrix", package=NULL,
-              old = as.character(sys.call(sys.parent()))[1L])
-  
-  return(hrm.test.matrix(data,alpha))
-}
-
-#' Test for no main treatment effect, no main time effect, no simple treatment effect and no interaction between treatment and time
-#' 
-#' @param data A list containing the data matrices of all groups. The rows are the independent subjects, these observations are assumed to be multivariate normally distributed. The columsn of all matrices need to be in the same order.
-#' @param alpha alpha level used for the test
-#' @return Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
-#' @example R/example_1.txt
-#' @keywords export
-hrm.test.matrix <- function(data, alpha=0.05){
+hrm.test.matrices <- function(data, alpha=0.05){
   
   if(!is.list(data)){
     stop("data needs to be a list containing the data matrices of all groups")
   }
   
   a <- length(data)
-  if(a < 2){
-    stop("At least two groups are needed.")
-  }
-  
   n <- rep(0,a)
+  d <- rep(0,a)
   for(i in 1:a){
     tmp <- data[[i]]
     if(!is.matrix(tmp)){
       stop("The elements of data need to be matrices.")
     }
     n[i] <- dim(tmp)[1]
+    d[i] <- dim(tmp)[2]
   }
-  d <- dim(data[[1]])[2]
-  d2 <- dim(data[[2]])[2]
-  if(d != d2){
+  
+  if(mean(d) != d[1]){
     stop("The number of measurements for each group need to be the same.")
   }
+  d <- d[1]
+ 
+  if(d < 2 & a < 2) {
+    stop("At least two measurements per subject or two groups are needed.")
+  }
   
-  stopifnot(is.list(data), all(is.finite(n)), alpha<=1, alpha>=0, d>=1, a>=1)
   
-  temp0 <- hrm.A.weighted(n,a,d,data,alpha)
-  temp1 <- hrm.A.unweighted(n,a,d,data,alpha)
-  temp2 <- hrm.B(n,a,d,data,alpha)
-  temp3 <- hrm.AB(n,a,d,data,alpha)
-  temp4 <- hrm.A_B(n,a,d,data,alpha)
+  # choose appropriate tests based on the number of factors present
+  testing <- rep(0, 5)
+  
+  if(a == 1 & d > 1) { testing <- c(0,0,1,0,0) }
+  if(a > 1 & d == 1) { testing <- c(1,1,0,0,0) }
+  if(a > 1 & d > 1) { testing <- c(1,1,1,1,1) }
+  
+  temp0 <- if(testing[1]) { hrm.A.weighted(n,a,d,data,alpha) }
+  temp1 <- if(testing[2]) { hrm.A.unweighted(n,a,d,data,alpha) }
+  temp2 <- if(testing[3]) { hrm.B(n,a,d,data,alpha) } 
+  temp3 <- if(testing[4]) { hrm.AB(n,a,d,data,alpha) }
+  temp4 <- if(testing[5]) { hrm.A_B(n,a,d,data,alpha) }
 
   output <- list()
   output$result <- rbind(temp0,temp1,temp2,temp3,temp4)
@@ -92,6 +82,7 @@ hrm.test.matrix <- function(data, alpha=0.05){
   output$alpha <- alpha
   output$subject <- NULL
   output$factors <- list(NULL, NULL)
+  output$data <- data
   class(output) <- "HRM"
   
   return (output)
@@ -123,6 +114,7 @@ hrm.test.2.one <- function(X, alpha, group , factor1, subject, data, testing = r
   output$alpha <- alpha
   output$subject <- subject
   output$factors <- list(c(group), c(factor1))
+  output$data <- X
   class(output) <- "HRM"
   
   return (output)
@@ -157,6 +149,7 @@ hrm.test.2.within <- function(X, alpha, group , factor1, factor2, subject, data,
   output$alpha <- alpha
   output$subject <- subject
   output$factors <- list(c(group), c(factor1, factor2))
+  output$data <- X
   class(output) <- "HRM"
   
   return (output)
@@ -193,6 +186,7 @@ hrm.test.2.between <- function(X, alpha, group , subgroup, factor, subject, data
   output$alpha <- alpha
   output$subject <- subject
   output$factors <- list(c(group, subgroup), c(factor))
+  output$data <- X
   class(output) <- "HRM"
  
   return (output)
@@ -228,6 +222,7 @@ hrm.test.2.between.within <- function(X, alpha, group , subgroup, factor1, facto
   output$alpha <- alpha
   output$subject <- subject
   output$factors <- list(c(group, subgroup), c(factor1, factor2))
+  output$data <- X
   class(output) <- "HRM"
   return (output)
 }
@@ -270,238 +265,29 @@ hrm.test.3.between <- function(X, alpha, group , factor1, factor2, factor3, subj
   output$alpha <- alpha
   output$subject <- subject
   output$factors <- list(c(group), c(factor1, factor2, factor3))
+  output$data <- X
   class(output) <- "HRM"
   return (output)
 }
 
 
-#' Test for main effects and interaction effects of one or two between-subject factors and one or two within-subject factors
+#' Test for Multi-Factor High-Dimensional Repeated Measures 
 #' 
-#' @param X A data.frame containing the data
-#' @param alpha alpha level used for the test
-#' @param group column name within the data frame data specifying the groups
-#' @param subgroup column name within the data frame data specifying the subgroups (crossed with groups)
-#' @param factor1 column name within the data frame data specifying the first subplot-factor
-#' @param factor2 column name within the data frame data specifying the the second subplot-factor (crossed with factor1)
-#' @param subject column name within the data frame X identifying the subjects
-#' @param data column name within the data frame X containing the response variable
-#' @return Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
-#' @example R/example_2.txt
-#' @keywords internal
-hrm.test.2 <- function(X, alpha = 0.05, group , subgroup, factor1, factor2, subject, data ){
-  .Deprecated("hrm.test.dataframe", package=NULL,
-              old = as.character(sys.call(sys.parent()))[1L])
-  return(hrm.test.dataframe(X, alpha, group , subgroup, factor1, factor2, subject, data ))
-}
-
-#' Test for main effects and interaction effects of one or two between-subject factors and one, two or three within-subject factors (at most four factors can be used).
-#' 
-#' @param data A data.frame containing the data
-#' @param alpha alpha level used for the test
-#' @param group column name within the data frame data specifying the groups
-#' @param subgroup column name within the data frame data specifying the subgroups (crossed with groups)
-#' @param factor1 column name within the data frame data specifying the first subplot-factor
-#' @param factor2 column name within the data frame data specifying the the second subplot-factor
-#' @param factor3 column name within the data frame data specifying the the third subplot-factor
-#' @param subject column name within the data frame X identifying the subjects
-#' @param response column name within the data frame X containing the response variable
-#' @return Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
-#' @example R/example_2.txt
-#' @keywords export
-hrm.test.dataframe <- function(data, alpha = 0.05, group , subgroup, factor1, factor2, factor3, subject, response ){
-  
-  temp <- data
-  data <- response
-  X <- temp
-  
-  # if(missing(factor1) || !is.character(factor1)){
-  #   print("At least one within-subject factor is needed!")
-  #   stop("factor1 column name not specified ")
-  # }
-  
-  # if(missing(group) || !is.character(group)){
-  #   print("At least one between-subject factor is needed!")
-  #   stop("group column name not specified ")
-  # }
-  
-  if(!missing(factor1) & !missing(factor2) & !missing(factor3) & !missing(group)  & !missing(subgroup)  ){
-    stop("The maximum number of factors that can be used is four.")
-  }
-  
-  if(missing(X) || !is.data.frame(X)){
-    stop("dataframe needed")
-  }
-  
-  if(missing(subject) || !is.character(subject)){
-    stop("subject column name not specified")
-  }
-  
-  if(missing(data) || !is.character(data)){
-    stop("data column name not specified")
-  }
-  
-  if(sum(is.na(X[,data]))>=1){
-    warning("Your data contains missing values!")
-  }
-  
-  if(!is.double(alpha)){
-    stop("alpha level needs to be a number between 0 and 1")
-  }
-  if(is.double(alpha)){
-    if(alpha > 1 || alpha < 0){
-      stop("alpha level needs to be a number between 0 and 1")
-    }
-  }
-  dat <- X
-  dat <- data.frame(dat, subj = X[,subject])
-  s1<-subset(dat, dat$subj==dat$subj[1])
-  measurements <- dim(s1)[1]
-  countSubplotFactor <- nlevels(s1[,factor1])
-  if(!missing(factor2)){
-    countSubplotFactor <- countSubplotFactor*nlevels(s1[,factor2])
-  }
-  if(!missing(factor3)){
-    countSubplotFactor <- countSubplotFactor*nlevels(s1[,factor3])
-  }
-  if(countSubplotFactor==0 & measurements == 1){
-    countSubplotFactor <- 1
-  }
-  if(!(measurements == countSubplotFactor)){
-    stop(paste("The number of repeated measurements per subject (", measurements, ") is uneqal to the number of levels of the subplot factors (", countSubplotFactor, ")."))
-  }
-  
-  # case: no subplot, one wholeplot
-  if(missing(factor2) & missing(subgroup) & missing(factor3) & missing(factor1) & !missing(group)){
-    
-    if(!is.factor(X[,group])){
-      stop(paste("The column ", group, " is not a factor." ))
-    }
-    
-    return(hrm.test.1.none(X, alpha , group, subject, data, formula = NULL ))
-  }
-
-  # case: one subplot, no wholeplot
-  if(missing(factor2) & missing(subgroup) & missing(factor3) & missing(group) & !missing(factor1)){
-    
-    if(!is.factor(X[,factor1])){
-      stop(paste("The column ", factor1, " is not a factor." ))
-    }
-    
-    return(hrm.test.1.one(X, alpha , factor1, subject, data, formula = NULL ))
-  }
-
-  
-  if(missing(factor2) & missing(subgroup) & missing(factor3)){
-    if(!is.factor(X[,group])){
-      stop(paste("The column ", group, " is not a factor." ))
-    }
-    if(!is.factor(X[,factor1])){
-      stop(paste("The column ", factor1, " is not a factor." ))
-    }
-    
-    return(hrm.test.2.one(X, alpha, group , factor1, subject, data, formula = NULL ))
-  }
-  
-  
-  if(missing(factor2) & !missing(subgroup) & missing(factor3)){
-    if(!is.character(subgroup)){
-      stop("subgroup column name not specified")
-    }
-    if(!is.factor(X[,group])){
-      stop(paste("The column ", group, " is not a factor." ))
-    }
-    if(!is.factor(X[,subgroup])){
-      stop(paste("The column ", subgroup, " is not a factor." ))
-    }
-    if(!is.factor(X[,factor1])){
-      stop(paste("The column ", factor1, " is not a factor." ))
-    }
-    return(hrm.test.2.between(X, alpha, group , subgroup, factor1, subject, data, formula = NULL))
-  }
-  
-  if(!missing(factor2) & missing(subgroup) & missing(factor3)){
-    if(!is.character(factor2)){
-      stop("factor2 column name not specified")
-    }
-    if(!is.factor(X[,group])){
-      stop(paste("The column ", group, " is not a factor." ))
-    }
-    if(!is.factor(X[,factor2])){
-      stop(paste("The column ", factor2, " is not a factor." ))
-    }
-    if(!is.factor(X[,factor1])){
-      stop(paste("The column ", factor1, " is not a factor." ))
-    }
-    return(hrm.test.2.within(X, alpha, group , factor1, factor2, subject, data, formula = NULL ))
-  }
-  
-  if(!missing(factor2) & !missing(subgroup) & missing(factor3)){
-    if(!is.character(factor2)){
-      stop("factor2 column name not specified")
-    }
-    if(!is.character(subgroup)){
-      stop("subgroup column name not specified")
-    }
-    if(!is.factor(X[,group])){
-      stop(paste("The column ", group, " is not a factor." ))
-    }
-    if(!is.factor(X[,subgroup])){
-      stop(paste("The column ", subgroup, " is not a factor." ))
-    }
-    if(!is.factor(X[,factor1])){
-      stop(paste("The column ", factor1, " is not a factor." ))
-    }
-    if(!is.factor(X[,factor2])){
-      stop(paste("The column ", factor2, " is not a factor." ))
-    }
-    return(hrm.test.2.between.within(X, alpha, group , subgroup, factor1, factor2, subject, data, formula = NULL))
-  }
-  if(!missing(factor1) & !missing(factor2) & !missing(factor3) & !missing(group)  & missing(subgroup)  ){
-    if(!is.character(factor1)){
-      stop("factor1 column name not specified")
-    }
-    if(!is.character(factor2)){
-      stop("factor2 column name not specified")
-    }
-    if(!is.character(factor3)){
-      stop("factor3 column name not specified")
-    }
-    if(!is.character(group)){
-      stop("group column name not specified")
-    }
-    if(!is.factor(X[,group])){
-      stop(paste("The column ", group, " is not a factor." ))
-    }
-    if(!is.factor(X[,factor1])){
-      stop(paste("The column ", factor1, " is not a factor." ))
-    }
-    if(!is.factor(X[,factor2])){
-      stop(paste("The column ", factor2, " is not a factor." ))
-    }
-    if(!is.factor(X[,factor3])){
-      stop(paste("The column ", factor3, " is not a factor." ))
-    }
-    formula <- as.formula(paste(data, "~", group, "*", factor1, "*", factor2, "*", factor3))
-    
-    return(hrm_test(formula=formula,alpha=alpha,subject=subject, data=X ))
-    
-  }
-  
-}
-
-
-
-#' Test for main effects and interaction effects of one or two between-subject factors and one, two or three within-subject factors (at most four factors can be used).
-#' 
-#' @param data A data.frame containing the data. The columns containing the factor variables need to have the type 'factor'. One column is needed to indentify the subjects.
-#' @param alpha alpha level used for the test
+#' @description Performing main and interaction effects of up to three whole- or subplot-factors. In total, a maximum of four factors can be used. There are two different S3 methods available. The first method requires a list of matrices in the wide table format. The second methodl requres a data.frame in the long table format.
+#' @param data Either a data.frame (one observation per row) or a list with matrices (one subject per row) for all groups containing the data
 #' @param formula A model formula object. The left hand side contains the response variable and the right hand side contains the whole- and subplot factors.
 #' @param subject column name within the data frame X identifying the subjects
-#' @return Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
-#' @example R/example_3.txt
-#' @keywords export
-hrm_test <- function(formula, data, alpha = 0.05,  subject ){
-  
+#' @param alpha alpha level used for calculating the critical value for the test
+#' @return Returns an object from class HRM containing
+#' @return \item{result}{A dataframe with the results from the hypotheses tests.}
+#' @return \item{formula}{The formula object which was used.}
+#' @return \item{alpha}{The type-I error rate which was used.}
+#' @return \item{subject}{The column name identifying the subjects.}
+#' @return \item{factors}{A list containing the whole- and subplot factors.}
+#' @return \item{data}{The data.frame or list containing the data.}
+#' @keywords internal
+hrm_test_internal <- function(formula, data, alpha = 0.05,  subject ){
+
   if(missing(data) || !is.data.frame(data)){
     stop("dataframe needed")
   }
@@ -516,16 +302,27 @@ hrm_test <- function(formula, data, alpha = 0.05,  subject ){
       stop("alpha level needs to be a number between 0 and 1")
     }
   }
+  
+  # convert whole/subplot factor columns to type factor
+  tryCatch({ 
+    nfactors <- length(attr(terms.formula(formula), "variables"))
+    for(i in 3:nfactors){
+      cname <- as.character(attr(terms.formula(formula), "variables")[[i]])
+      if( !is.factor( data[,cname] ) ) {
+        data[,cname] <- as.factor(data[,cname])
+      }
+    }
+  }, warning = function(w) "", error = function(e) { paste("One of the factor columns could not be converted to a factor variable." ) } )
+  
   dat <- model.frame(formula, data)
   dat2 <- data.frame(dat,subj=data[,subject])
+
   m <- ncol(dat)
   
   if(!is.numeric(dat[,1])){
     stop("Response variable needs to be numeric!")
   }
   
-  
-  
   # find out, in which columns are the wholeplot or subplot factors
   s1<-subset(dat2, dat2$subj==dat2$subj[1])
   measurements <- dim(s1)[1]
@@ -546,7 +343,8 @@ hrm_test <- function(formula, data, alpha = 0.05,  subject ){
   }
   wholeplot <- which(wholeplot==1)
   subplot <- which( subplot==1)
-
+  
+  
   if(!(measurements == countSubplotFactor)){
     stop(paste("The number of repeated measurements per subject (", measurements, ") is uneqal to the number of levels of the subplot factors (", countSubplotFactor, ")."))
   }
@@ -562,6 +360,9 @@ hrm_test <- function(formula, data, alpha = 0.05,  subject ){
   if(length(subplot)<1 & length(wholeplot)>1){
     stop("The model needs at least one within-subject factor.")
   }
+  if(length(subplot)>1 & length(wholeplot)<1){
+    stop("The model supports only one subplot-factor when using no wholeplot-factors.")
+  }
   
   # Case: no wholeplot, one subpot factor
   if(length(wholeplot) < 1 & length(subplot) == 1){
